@@ -110,7 +110,7 @@ enum {
 
 
 struct _EelCanvasItem {
-	GtkObject object;
+	GInitiallyUnowned object;
 
 	/* Parent canvas for this item */
 	EelCanvas *canvas;
@@ -126,7 +126,9 @@ struct _EelCanvasItem {
 };
 
 struct _EelCanvasItemClass {
-	GtkObjectClass parent_class;
+	GInitiallyUnownedClass parent_class;
+
+	void (* destroy) (EelCanvasItem *item);
 
 	/* Tell the item to update itself.  The flags are from the update flags
 	 * defined above.  The item should update its internal state from its
@@ -151,7 +153,7 @@ struct _EelCanvasItemClass {
 	 * coordinates of the drawable, a temporary pixmap, where things get
 	 * drawn.  (width, height) are the dimensions of the drawable.
 	 */
-	void (* draw) (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose);
+	void (* draw) (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region);
 
 	/* Calculate the distance from an item to the specified point.  It also
          * returns a canvas item which is the item itself in the case of the
@@ -189,6 +191,8 @@ GType eel_canvas_item_get_type (void) G_GNUC_CONST;
 EelCanvasItem *eel_canvas_item_new (EelCanvasGroup *parent, GType type,
 				    const gchar *first_arg_name, ...);
 
+void eel_canvas_item_destroy (EelCanvasItem *item);
+
 /* Constructors for use in derived classes and language wrappers */
 void eel_canvas_item_construct (EelCanvasItem *item, EelCanvasGroup *parent,
 				const gchar *first_arg_name, va_list args);
@@ -420,7 +424,7 @@ struct _EelCanvasClass {
 	/* Draw the background for the area given.
 	 */
 	void (* draw_background) (EelCanvas *canvas,
-				  int x, int y, int width, int height);
+                                  cairo_t *cr);
 
 	/* Private Virtual methods for groping the canvas inside bonobo */
 	void (* request_update) (EelCanvas *canvas);
