@@ -69,31 +69,6 @@ typedef enum {
 	EEL_GDK_Y_NEGATIVE   = 0x20
 } EelGdkGeometryFlags;
 
-/* A gradient spec. is a string that contains a specifier for either a
-   color or a gradient. If the string has a "-" in it, then it's a gradient.
-   The gradient is vertical by default and the spec. can end with ":v" to indicate that.
-   If the gradient ends with ":h", the gradient is horizontal.
-*/
-char *              eel_gradient_new                       (const char          *start_color,
-							    const char          *end_color,
-							    gboolean             is_horizontal);
-char *              eel_gradient_parse_one_color_spec      (const char          *spec,
-							    int                 *percent,
-							    const char         **next_spec);
-gboolean            eel_gradient_is_gradient               (const char          *gradient_spec);
-char *              eel_gradient_get_start_color_spec      (const char          *gradient_spec);
-char *              eel_gradient_get_end_color_spec        (const char          *gradient_spec);
-gboolean            eel_gradient_is_horizontal             (const char          *gradient_spec);
-char *              eel_gradient_set_left_color_spec       (const char          *gradient_spec,
-							    const char          *left_color);
-char *              eel_gradient_set_top_color_spec        (const char          *gradient_spec,
-							    const char          *top_color);
-char *              eel_gradient_set_right_color_spec      (const char          *gradient_spec,
-							    const char          *right_color);
-char *              eel_gradient_set_bottom_color_spec     (const char          *gradient_spec,
-							    const char          *bottom_color);
-
-
 /* A version of parse_color that substitutes a default color instead of returning
    a boolean to indicate it cannot be parsed.
 */
@@ -123,4 +98,6 @@ void                eel_cairo_draw_layout_with_drop_shadow (cairo_t
 							    int                  x,
 							    int                  y,
 							    PangoLayout         *layout);
+void                eel_make_color_inactive                (GdkColor            *color);
+
 #endif /* EEL_GDK_EXTENSIONS_H */
