@@ -141,7 +141,7 @@ typedef struct {
 	NautilusIconInfo *(* get_icon_images)     (NautilusIconContainer *container,
 						   NautilusIconData *data,
 						   int icon_size,
-						   GList **emblem_pixbufs,
+						   GList **emblem_icons,
 						   char **embedded_text,
 						   gboolean for_drag_accept,
 						   gboolean need_large_embeddded_text,
@@ -351,6 +351,8 @@ void              nautilus_icon_container_set_store_layout_timestamps   (Nautilu
 
 void              nautilus_icon_container_widget_to_file_operation_position (NautilusIconContainer *container,
 									     GdkPoint              *position);
+void              nautilus_icon_container_set_active                    (NautilusIconContainer  *container,
+									 gboolean                active);
 
 
 #define CANVAS_WIDTH(container,allocation) ((allocation.width	  \
