@@ -58,6 +58,8 @@ NautilusIconInfo *    nautilus_icon_info_lookup                       (GIcon
 								       int                size);
 NautilusIconInfo *    nautilus_icon_info_lookup_from_name             (const char        *name,
 								       int                size);
+NautilusIconInfo *    nautilus_icon_info_lookup_from_path             (const char        *path,
+								       int                size);
 gboolean              nautilus_icon_info_is_fallback                  (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf                   (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf_nodefault         (NautilusIconInfo  *icon);
@@ -85,6 +87,9 @@ guint nautilus_icon_get_smaller_icon_size            (guint              size);
 gint  nautilus_get_icon_size_for_stock_size          (GtkIconSize        size);
 guint nautilus_icon_get_emblem_size_for_icon_size    (guint              size);
 
+gboolean nautilus_icon_theme_can_render              (GThemedIcon *icon);
+GIcon * nautilus_user_special_directory_get_gicon (GUserDirectory directory);
+
 
 G_END_DECLS
 
