@@ -47,7 +47,6 @@
 #include <libnautilus-private/nautilus-column-chooser.h>
 #include <libnautilus-private/nautilus-column-utilities.h>
 #include <libnautilus-private/nautilus-debug-log.h>
-#include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-dnd.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -1002,13 +1001,13 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 	handled = FALSE;
 
 	switch (event->keyval) {
-	case GDK_F10:
+	case GDK_KEY_F10:
 		if (event->state & GDK_CONTROL_MASK) {
 			fm_directory_view_pop_up_background_context_menu (view, &button_event);
 			handled = TRUE;
 		}
 		break;
-	case GDK_Right:
+	case GDK_KEY_Right:
 		gtk_tree_view_get_cursor (tree_view, &path, NULL);
 		if (path) {
 			gtk_tree_view_expand_row (tree_view, path, FALSE);
@@ -1016,7 +1015,7 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_Left:
+	case GDK_KEY_Left:
 		gtk_tree_view_get_cursor (tree_view, &path, NULL);
 		if (path) {
 			gtk_tree_view_collapse_row (tree_view, path);
@@ -1024,7 +1023,7 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_space:
+	case GDK_KEY_space:
 		if (event->state & GDK_CONTROL_MASK) {
 			handled = FALSE;
 			break;
@@ -1040,8 +1039,8 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_Return:
-	case GDK_KP_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter:
 		if ((event->state & GDK_SHIFT_MASK) != 0) {
 			activate_selected_items_alternate (FM_LIST_VIEW (view), NULL, TRUE);
 		} else {
@@ -1049,7 +1048,7 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_v:
+	case GDK_KEY_v:
 		/* Eat Control + v to not enable type ahead */
 		if ((event->state & GDK_CONTROL_MASK) != 0) {
 			handled = TRUE;
@@ -1177,6 +1176,32 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 	view->details->last_sort_attr = sort_attr;
 }
 
+static void
+cell_renderer_editing_started_cb (GtkCellRenderer *renderer,
+				  GtkCellEditable *editable,
+				  const gchar *path_str,
+				  FMListView *list_view)
+{
+	GtkEntry *entry;
+	gint start_offset, end_offset;
+
+	entry = GTK_ENTRY (editable);
+	list_view->details->editable_widget = editable;
+
+	/* Free a previously allocated original_name */
+	g_free (list_view->details->original_name);
+
+	list_view->details->original_name = g_strdup (gtk_entry_get_text (entry));
+	eel_filename_get_rename_region (list_view->details->original_name,
+					&start_offset, &end_offset);
+	gtk_editable_select_region (GTK_EDITABLE (entry), start_offset, end_offset);
+
+	nautilus_clipboard_set_up_editable
+		(GTK_EDITABLE (entry),
+		 fm_directory_view_get_ui_manager (FM_DIRECTORY_VIEW (list_view)),
+		 FALSE);
+}
+
 static void
 cell_renderer_editing_canceled (GtkCellRendererText *cell,
 				FMListView          *view)
@@ -1476,7 +1501,7 @@ create_and_set_up_tree_view (FMListView *view)
 
 	/* Don't handle backspace key. It's used to open the parent folder. */
 	binding_set = gtk_binding_set_by_class (GTK_WIDGET_GET_CLASS (view->details->tree_view));
-	gtk_binding_entry_remove (binding_set, GDK_BackSpace, 0);
+	gtk_binding_entry_remove (binding_set, GDK_KEY_BackSpace, 0);
 
 	view->details->drag_dest = 
 		nautilus_tree_view_drag_dest_new (view->details->tree_view);
@@ -1599,7 +1624,8 @@ create_and_set_up_tree_view (FMListView *view)
 			view->details->file_name_cell = (GtkCellRendererText *)cell;
 			g_signal_connect (cell, "edited", G_CALLBACK (cell_renderer_edited), view);
 			g_signal_connect (cell, "editing-canceled", G_CALLBACK (cell_renderer_editing_canceled), view);
-			
+			g_signal_connect (cell, "editing-started", G_CALLBACK (cell_renderer_editing_started_cb), view);
+
 			gtk_tree_view_column_pack_start (view->details->file_name_column, cell, TRUE);
 			gtk_tree_view_column_set_cell_data_func (view->details->file_name_column, cell,
 								 (GtkTreeCellDataFunc) filename_cell_data_func,
@@ -1918,12 +1944,6 @@ fm_list_view_file_changed (FMDirectoryView *view, NautilusFile *file, NautilusDi
 	}
 }
 
-static GtkWidget *
-fm_list_view_get_background_widget (FMDirectoryView *view)
-{
-	return GTK_WIDGET (view);
-}
-
 static void
 fm_list_view_get_selection_foreach_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
@@ -2116,7 +2136,7 @@ fm_list_view_set_selection (FMDirectoryView *view, GList *selection)
 			gtk_tree_selection_select_iter (tree_selection,
 							(GtkTreeIter *)l->data);
 		}
-		eel_g_list_free_deep (iters);
+		g_list_free_full (iters, g_free);
 	}
 
 	g_signal_handlers_unblock_by_func (tree_selection, list_selection_changed_callback, view);
@@ -2151,7 +2171,7 @@ fm_list_view_invert_selection (FMDirectoryView *view)
 			gtk_tree_selection_unselect_iter (tree_selection,
 							(GtkTreeIter *)l->data);
 		}
-		eel_g_list_free_deep (iters);
+		g_list_free_full (iters, g_free);
 	}
 
 	g_list_free (selection);
@@ -2626,11 +2646,6 @@ fm_list_view_start_renaming_file (FMDirectoryView *view,
 	FMListView *list_view;
 	GtkTreeIter iter;
 	GtkTreePath *path;
-	GtkEntry *entry;
-	int start_offset, end_offset;
-	gchar *path_str;
-	GdkRectangle cell_area;
-	GdkRectangle background_area;
 	
 	list_view = FM_LIST_VIEW (view);
 	
@@ -2651,21 +2666,12 @@ fm_list_view_start_renaming_file (FMDirectoryView *view,
 	fm_directory_view_freeze_updates (FM_DIRECTORY_VIEW (view));
 
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_view->details->model), &iter);
-	path_str = gtk_tree_path_to_string (path);
-	gtk_tree_view_get_cell_area (list_view->details->tree_view, path,
-				     list_view->details->file_name_column, &cell_area);
-	gtk_tree_view_get_background_area (list_view->details->tree_view, path,
-					   list_view->details->file_name_column, &background_area);
 
 	/* Make filename-cells editable. */
 	g_object_set (G_OBJECT (list_view->details->file_name_cell),
 		      "editable", TRUE,
 		      NULL);
 
-	list_view->details->editable_widget =
-		gtk_cell_renderer_start_editing (GTK_CELL_RENDERER (list_view->details->file_name_cell),
-						 NULL, NULL, path_str, &background_area,
-						 &cell_area, 0);
 	gtk_tree_view_scroll_to_cell (list_view->details->tree_view,
 				      NULL,
 				      list_view->details->file_name_column,
@@ -2675,27 +2681,7 @@ fm_list_view_start_renaming_file (FMDirectoryView *view,
 				  list_view->details->file_name_column,
 				  TRUE);
 
-	entry = GTK_ENTRY (list_view->details->editable_widget);
-
-	/* Free a previously allocated original_name */
-	g_free (list_view->details->original_name);
-
-	list_view->details->original_name = g_strdup (gtk_entry_get_text (entry));
-	if (select_all) {
-		start_offset = 0;
-		end_offset = -1;
-	} else {
-		eel_filename_get_rename_region (list_view->details->original_name,
-						&start_offset, &end_offset);
-	}
-	gtk_editable_select_region (GTK_EDITABLE (entry), start_offset, end_offset);
-	
 	gtk_tree_path_free (path);
-
-	nautilus_clipboard_set_up_editable
-		(GTK_EDITABLE (entry),
-		 fm_directory_view_get_ui_manager (view),
-		 FALSE);
 }
 
 static void
@@ -2981,6 +2967,13 @@ list_view_notify_clipboard_info (NautilusClipboardMonitor *monitor,
                                  NautilusClipboardInfo *info,
                                  FMListView *view)
 {
+	/* this could be called as a result of _end_loading() being
+	 * called after _dispose(), where the model is cleared.
+	 */
+	if (view->details->model == NULL) {
+		return;
+	}
+
 	if (info != NULL && info->cut) {
 		fm_list_model_set_highlight_for_files (view->details->model, info->files);
 	} else {
@@ -3005,22 +2998,20 @@ static void
 real_set_is_active (FMDirectoryView *view,
 		    gboolean is_active)
 {
-	GtkWidget *tree_view;
-	GtkStyle *style;
+	GtkWidget *widget;
 	GdkColor color;
+	GtkStyle *style;
 
-	tree_view = GTK_WIDGET (fm_list_view_get_tree_view (FM_LIST_VIEW (view)));
+	widget = GTK_WIDGET (fm_list_view_get_tree_view (FM_LIST_VIEW (view)));
+	style = gtk_widget_get_style (widget);
 
-	if (is_active) {
-		gtk_widget_modify_base (tree_view, GTK_STATE_NORMAL, NULL);
+	if (!is_active) {
+		color = style->base[GTK_STATE_NORMAL];
+		eel_make_color_inactive (&color);
+		gtk_widget_modify_base (widget, GTK_STATE_NORMAL, &color);
 	} else {
-		style = gtk_widget_get_style (tree_view);
-		color = style->base[GTK_STATE_INSENSITIVE];
-		gtk_widget_modify_base (tree_view, GTK_STATE_NORMAL, &color);
+		gtk_widget_modify_base (widget, GTK_STATE_NORMAL, NULL);
 	}
-
-	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS,
-			 set_is_active, (view, is_active));
 }
 
 static void
@@ -3042,7 +3033,6 @@ fm_list_view_class_init (FMListViewClass *class)
         fm_directory_view_class->click_policy_changed = fm_list_view_click_policy_changed;
 	fm_directory_view_class->clear = fm_list_view_clear;
 	fm_directory_view_class->file_changed = fm_list_view_file_changed;
-	fm_directory_view_class->get_background_widget = fm_list_view_get_background_widget;
 	fm_directory_view_class->get_selection = fm_list_view_get_selection;
 	fm_directory_view_class->get_selection_for_file_transfer = fm_list_view_get_selection_for_file_transfer;
 	fm_directory_view_class->get_item_count = fm_list_view_get_item_count;
