@@ -29,7 +29,6 @@
 #include <config.h>
 #include "fm-tree-model.h"
 
-#include <eel/eel-glib-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-directory.h>
@@ -275,8 +274,7 @@ get_menu_icon_for_file (TreeNode *node,
 	int i;
 
 	size = nautilus_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU);
-
-	gicon = nautilus_file_get_gicon (file, flags);
+	gicon = G_ICON (nautilus_file_get_icon_pixbuf (file, size, TRUE, flags));
 
 	i = 0;
 	emblems_to_ignore[i++] = NAUTILUS_FILE_EMBLEM_NAME_TRASH;
@@ -308,7 +306,7 @@ get_menu_icon_for_file (TreeNode *node,
 		}
 	}
 
-	eel_g_object_list_free (emblem_icons);
+	g_list_free_full (emblem_icons, g_object_unref);
 
 	info = nautilus_icon_info_lookup (gicon, size);
 	retval = nautilus_icon_info_get_pixbuf_nodefault_at_size (info, size);
