@@ -25,14 +25,10 @@
 #include <config.h>
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
-#include <libgnome/gnome-program.h>
-#include <libgnomeui/gnome-ui-init.h>
 #include <libnautilus-private/nautilus-module.h>
-
-#include <libintl.h>
-
-#include <eel/eel-preferences.h>
+#include <libnautilus-private/nautilus-global-preferences.h>
 
 #include "nautilus-file-management-properties.h"
 
@@ -52,13 +48,11 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("file-managment-properties", VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    NULL, NULL);
+	gtk_init (&argc, &argv);
 
-	eel_preferences_init ("/apps/nautilus");
+	nautilus_global_preferences_init ();
 
-	nautilus_module_init ();
+	nautilus_module_setup ();
 
 	nautilus_file_management_properties_dialog_show (G_CALLBACK (nautilus_file_management_properties_main_close_callback), NULL);
 
