@@ -59,16 +59,6 @@ nautilus_location_dialog_finalize (GObject *object)
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
-static void
-nautilus_location_dialog_destroy (GtkObject *object)
-{
-	NautilusLocationDialog *dialog;
-
-	dialog = NAUTILUS_LOCATION_DIALOG (object);
-	
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
-}
-
 static void
 open_current_location (NautilusLocationDialog *dialog)
 {
@@ -132,13 +122,9 @@ static void
 nautilus_location_dialog_class_init (NautilusLocationDialogClass *class)
 {
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
 
 	gobject_class = G_OBJECT_CLASS (class);
-	gobject_class->finalize = nautilus_location_dialog_finalize;
-	
-	object_class = GTK_OBJECT_CLASS (class);
-	object_class->destroy = nautilus_location_dialog_destroy;
+	gobject_class->finalize = nautilus_location_dialog_finalize;	
 }
 
 static void
@@ -166,7 +152,6 @@ nautilus_location_dialog_init (NautilusLocationDialog *dialog)
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Open Location"));
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 300, -1);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 	
