@@ -123,19 +123,19 @@ static gboolean
 entry_would_have_inserted_characters (const GdkEventKey *event)
 {
 	switch (event->keyval) {
-	case GDK_BackSpace:
-	case GDK_Clear:
-	case GDK_Insert:
-	case GDK_Delete:
-	case GDK_Home:
-	case GDK_End:
-	case GDK_KP_Home:
-	case GDK_KP_End:
-	case GDK_Left:
-	case GDK_Right:
-	case GDK_KP_Left:
-	case GDK_KP_Right:
-	case GDK_Return:
+	case GDK_KEY_BackSpace:
+	case GDK_KEY_Clear:
+	case GDK_KEY_Insert:
+	case GDK_KEY_Delete:
+	case GDK_KEY_Home:
+	case GDK_KEY_End:
+	case GDK_KEY_KP_Home:
+	case GDK_KEY_KP_End:
+	case GDK_KEY_Left:
+	case GDK_KEY_Right:
+	case GDK_KEY_KP_Left:
+	case GDK_KEY_KP_Right:
+	case GDK_KEY_Return:
 		return FALSE;
 	default:
 		if (event->keyval >= 0x20 && event->keyval <= 0xFF) {
@@ -218,7 +218,7 @@ editable_event_after_callback (GtkEntry *entry,
 	 * likely an auto-completion. We ignore shift / control since
 	 * they can validly be used to extend the selection.
 	 */
-	if ((keyevent->keyval == GDK_Right || keyevent->keyval == GDK_End) &&
+	if ((keyevent->keyval == GDK_KEY_Right || keyevent->keyval == GDK_KEY_End) &&
 	    !(keyevent->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)) && 
 	    gtk_editable_get_selection_bounds (editable, NULL, NULL)) {
 		set_position_and_selection_to_end (editable);
@@ -261,7 +261,7 @@ finalize (GObject *object)
 }
 
 static void
-destroy (GtkObject *object)
+destroy (GtkWidget *object)
 {
 	NautilusLocationEntry *entry;
 
@@ -276,7 +276,7 @@ destroy (GtkObject *object)
 	g_free (entry->details->current_directory);
 	entry->details->current_directory = NULL;
 	
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_WIDGET_CLASS, destroy, (object));
 }
 
 static void
@@ -354,17 +354,14 @@ nautilus_location_entry_class_init (NautilusLocationEntryClass *class)
 {
 	GtkWidgetClass *widget_class;
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
 	GtkEntryClass *entry_class;
 
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->focus_in_event = nautilus_location_entry_focus_in;
+	widget_class->destroy = destroy;
 
 	gobject_class = G_OBJECT_CLASS (class);
 	gobject_class->finalize = finalize;
-	
-	object_class = GTK_OBJECT_CLASS (class);
-	object_class->destroy = destroy;
 
 	entry_class = GTK_ENTRY_CLASS (class);
 	entry_class->activate = nautilus_location_entry_activate;
