@@ -803,9 +803,8 @@ type_add_rows_from_query (NautilusQueryEditor    *editor,
 		gtk_combo_box_set_active_iter  (GTK_COMBO_BOX (row->type_widget),
 						&iter);
 	}
-	
-	eel_g_list_free_deep (mime_types);
 
+	g_list_free_full (mime_types, g_free);
 }
 
 /* End of row types */
@@ -901,10 +900,10 @@ nautilus_query_editor_add_row (NautilusQueryEditor *editor,
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (editor->details->visible_vbox), hbox, FALSE, FALSE, 0);
 
-	combo = gtk_combo_box_new_text ();
+	combo = gtk_combo_box_text_new ();
 	row->combo = combo;
 	for (i = 0; i < NAUTILUS_QUERY_EDITOR_ROW_LAST; i++) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), gettext (row_type[i].name));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), gettext (row_type[i].name));
 	}
 	gtk_widget_show (combo);
 	gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
